Documentation
¶
Index ¶
- Variables
- type EnumDescriptor
- type EnumDescriptor_Value
- func (*EnumDescriptor_Value) Descriptor() ([]byte, []int)deprecated
- func (x *EnumDescriptor_Value) GetAlias() string
- func (x *EnumDescriptor_Value) GetName() string
- func (x *EnumDescriptor_Value) GetNumber() int32
- func (*EnumDescriptor_Value) ProtoMessage()
- func (x *EnumDescriptor_Value) ProtoReflect() protoreflect.Message
- func (x *EnumDescriptor_Value) Reset()
- func (x *EnumDescriptor_Value) String() string
- type Field
- func (*Field) Descriptor() ([]byte, []int)deprecated
- func (x *Field) GetAlias() string
- func (x *Field) GetFields() []*Field
- func (x *Field) GetFullType() string
- func (x *Field) GetListEntry() *Field_ListEntry
- func (x *Field) GetMapEntry() *Field_MapEntry
- func (x *Field) GetName() string
- func (x *Field) GetNumber() int32
- func (x *Field) GetOptions() *tableaupb.FieldOptions
- func (x *Field) GetPredefined() bool
- func (x *Field) GetType() string
- func (*Field) ProtoMessage()
- func (x *Field) ProtoReflect() protoreflect.Message
- func (x *Field) Reset()
- func (x *Field) String() string
- type Field_ListEntry
- func (*Field_ListEntry) Descriptor() ([]byte, []int)deprecated
- func (x *Field_ListEntry) GetElemFullType() string
- func (x *Field_ListEntry) GetElemType() string
- func (*Field_ListEntry) ProtoMessage()
- func (x *Field_ListEntry) ProtoReflect() protoreflect.Message
- func (x *Field_ListEntry) Reset()
- func (x *Field_ListEntry) String() string
- type Field_MapEntry
- func (*Field_MapEntry) Descriptor() ([]byte, []int)deprecated
- func (x *Field_MapEntry) GetKeyType() string
- func (x *Field_MapEntry) GetValueFullType() string
- func (x *Field_MapEntry) GetValueType() string
- func (*Field_MapEntry) ProtoMessage()
- func (x *Field_MapEntry) ProtoReflect() protoreflect.Message
- func (x *Field_MapEntry) Reset()
- func (x *Field_MapEntry) String() string
- type Metabook
- type Metasheet
- func (*Metasheet) Descriptor() ([]byte, []int)deprecated
- func (x *Metasheet) GetAdjacentKey() bool
- func (x *Metasheet) GetAlias() string
- func (x *Metasheet) GetDatarow() int32
- func (x *Metasheet) GetFieldPresence() bool
- func (x *Metasheet) GetIndex() string
- func (x *Metasheet) GetLabels() map[string]string
- func (x *Metasheet) GetLangOptions() map[string]string
- func (x *Metasheet) GetMerger() []string
- func (x *Metasheet) GetMode() tableaupb.Mode
- func (x *Metasheet) GetNameline() int32
- func (x *Metasheet) GetNamerow() int32
- func (x *Metasheet) GetNested() bool
- func (x *Metasheet) GetNoterow() int32
- func (x *Metasheet) GetOptional() bool
- func (x *Metasheet) GetOrderedMap() bool
- func (x *Metasheet) GetPatch() tableaupb.Patch
- func (x *Metasheet) GetScatter() []string
- func (x *Metasheet) GetScatterWithoutBookName() bool
- func (x *Metasheet) GetSep() string
- func (x *Metasheet) GetSheet() string
- func (x *Metasheet) GetSubsep() string
- func (x *Metasheet) GetTemplate() bool
- func (x *Metasheet) GetTranspose() bool
- func (x *Metasheet) GetTypeline() int32
- func (x *Metasheet) GetTyperow() int32
- func (x *Metasheet) GetWithParentDir() bool
- func (*Metasheet) ProtoMessage()
- func (x *Metasheet) ProtoReflect() protoreflect.Message
- func (x *Metasheet) Reset()
- func (x *Metasheet) String() string
- type StructDescriptor
- func (*StructDescriptor) Descriptor() ([]byte, []int)deprecated
- func (x *StructDescriptor) GetFields() []*StructDescriptor_Field
- func (*StructDescriptor) ProtoMessage()
- func (x *StructDescriptor) ProtoReflect() protoreflect.Message
- func (x *StructDescriptor) Reset()
- func (x *StructDescriptor) String() string
- type StructDescriptor_Field
- func (*StructDescriptor_Field) Descriptor() ([]byte, []int)deprecated
- func (x *StructDescriptor_Field) GetName() string
- func (x *StructDescriptor_Field) GetType() string
- func (*StructDescriptor_Field) ProtoMessage()
- func (x *StructDescriptor_Field) ProtoReflect() protoreflect.Message
- func (x *StructDescriptor_Field) Reset()
- func (x *StructDescriptor_Field) String() string
- type UnionDescriptor
- func (*UnionDescriptor) Descriptor() ([]byte, []int)deprecated
- func (x *UnionDescriptor) GetValues() []*UnionDescriptor_Value
- func (*UnionDescriptor) ProtoMessage()
- func (x *UnionDescriptor) ProtoReflect() protoreflect.Message
- func (x *UnionDescriptor) Reset()
- func (x *UnionDescriptor) String() string
- type UnionDescriptor_Value
- func (*UnionDescriptor_Value) Descriptor() ([]byte, []int)deprecated
- func (x *UnionDescriptor_Value) GetAlias() string
- func (x *UnionDescriptor_Value) GetFields() []string
- func (x *UnionDescriptor_Value) GetName() string
- func (x *UnionDescriptor_Value) GetNumber() int32
- func (*UnionDescriptor_Value) ProtoMessage()
- func (x *UnionDescriptor_Value) ProtoReflect() protoreflect.Message
- func (x *UnionDescriptor_Value) Reset()
- func (x *UnionDescriptor_Value) String() string
- type Workbook
- func (*Workbook) Descriptor() ([]byte, []int)deprecated
- func (x *Workbook) GetImports() map[string]int32
- func (x *Workbook) GetName() string
- func (x *Workbook) GetOptions() *tableaupb.WorkbookOptions
- func (x *Workbook) GetWorksheets() []*Worksheet
- func (*Workbook) ProtoMessage()
- func (x *Workbook) ProtoReflect() protoreflect.Message
- func (x *Workbook) Reset()
- func (x *Workbook) String() string
- type Worksheet
- func (*Worksheet) Descriptor() ([]byte, []int)deprecated
- func (x *Worksheet) GetFields() []*Field
- func (x *Worksheet) GetName() string
- func (x *Worksheet) GetNote() string
- func (x *Worksheet) GetOptions() *tableaupb.WorksheetOptions
- func (*Worksheet) ProtoMessage()
- func (x *Worksheet) ProtoReflect() protoreflect.Message
- func (x *Worksheet) Reset()
- func (x *Worksheet) String() string
Constants ¶
This section is empty.
Variables ¶
var File_tableau_protobuf_internal_metabook_proto protoreflect.FileDescriptor
var File_tableau_protobuf_internal_workbook_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type EnumDescriptor ¶
type EnumDescriptor struct {
Values []*EnumDescriptor_Value `protobuf:"bytes,1,rep,name=values,proto3" json:"values,omitempty"`
// contains filtered or unexported fields
}
EnumDescriptor represents enum type definition in sheet.
func (*EnumDescriptor) Descriptor
deprecated
func (*EnumDescriptor) Descriptor() ([]byte, []int)
Deprecated: Use EnumDescriptor.ProtoReflect.Descriptor instead.
func (*EnumDescriptor) GetValues ¶
func (x *EnumDescriptor) GetValues() []*EnumDescriptor_Value
func (*EnumDescriptor) ProtoMessage ¶
func (*EnumDescriptor) ProtoMessage()
func (*EnumDescriptor) ProtoReflect ¶
func (x *EnumDescriptor) ProtoReflect() protoreflect.Message
func (*EnumDescriptor) Reset ¶
func (x *EnumDescriptor) Reset()
func (*EnumDescriptor) String ¶
func (x *EnumDescriptor) String() string
type EnumDescriptor_Value ¶
type EnumDescriptor_Value struct {
Number *int32 `protobuf:"varint,1,opt,name=number,proto3,oneof" json:"number,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
Alias string `protobuf:"bytes,3,opt,name=alias,proto3" json:"alias,omitempty"`
// contains filtered or unexported fields
}
func (*EnumDescriptor_Value) Descriptor
deprecated
func (*EnumDescriptor_Value) Descriptor() ([]byte, []int)
Deprecated: Use EnumDescriptor_Value.ProtoReflect.Descriptor instead.
func (*EnumDescriptor_Value) GetAlias ¶
func (x *EnumDescriptor_Value) GetAlias() string
func (*EnumDescriptor_Value) GetName ¶
func (x *EnumDescriptor_Value) GetName() string
func (*EnumDescriptor_Value) GetNumber ¶
func (x *EnumDescriptor_Value) GetNumber() int32
func (*EnumDescriptor_Value) ProtoMessage ¶
func (*EnumDescriptor_Value) ProtoMessage()
func (*EnumDescriptor_Value) ProtoReflect ¶
func (x *EnumDescriptor_Value) ProtoReflect() protoreflect.Message
func (*EnumDescriptor_Value) Reset ¶
func (x *EnumDescriptor_Value) Reset()
func (*EnumDescriptor_Value) String ¶
func (x *EnumDescriptor_Value) String() string
type Field ¶
type Field struct {
// Field tag number
// Note: only for enum/struct/union type definition in sheet
Number int32 `protobuf:"varint,1,opt,name=number,proto3" json:"number,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
Alias string `protobuf:"bytes,3,opt,name=alias,proto3" json:"alias,omitempty"`
Type string `protobuf:"bytes,4,opt,name=type,proto3" json:"type,omitempty"`
FullType string `protobuf:"bytes,5,opt,name=full_type,json=fullType,proto3" json:"full_type,omitempty"`
ListEntry *Field_ListEntry `protobuf:"bytes,6,opt,name=list_entry,json=listEntry,proto3" json:"list_entry,omitempty"`
MapEntry *Field_MapEntry `protobuf:"bytes,7,opt,name=map_entry,json=mapEntry,proto3" json:"map_entry,omitempty"`
// Indicate whether this field's related type is predefined.
// - enum: enum type
// - struct: message type
// - list: list's element type
// - map: map's value type
Predefined bool `protobuf:"varint,8,opt,name=predefined,proto3" json:"predefined,omitempty"`
Options *tableaupb.FieldOptions `protobuf:"bytes,9,opt,name=options,proto3" json:"options,omitempty"`
// This field can be struct, list or map if sub fields's length is not 0.
Fields []*Field `protobuf:"bytes,10,rep,name=fields,proto3" json:"fields,omitempty"`
// contains filtered or unexported fields
}
func (*Field) Descriptor
deprecated
func (*Field) GetFullType ¶
func (*Field) GetListEntry ¶
func (x *Field) GetListEntry() *Field_ListEntry
func (*Field) GetMapEntry ¶
func (x *Field) GetMapEntry() *Field_MapEntry
func (*Field) GetOptions ¶
func (x *Field) GetOptions() *tableaupb.FieldOptions
func (*Field) GetPredefined ¶
func (*Field) ProtoMessage ¶
func (*Field) ProtoMessage()
func (*Field) ProtoReflect ¶
func (x *Field) ProtoReflect() protoreflect.Message
type Field_ListEntry ¶
type Field_ListEntry struct {
ElemType string `protobuf:"bytes,1,opt,name=elem_type,json=elemType,proto3" json:"elem_type,omitempty"`
ElemFullType string `protobuf:"bytes,2,opt,name=elem_full_type,json=elemFullType,proto3" json:"elem_full_type,omitempty"`
// contains filtered or unexported fields
}
func (*Field_ListEntry) Descriptor
deprecated
func (*Field_ListEntry) Descriptor() ([]byte, []int)
Deprecated: Use Field_ListEntry.ProtoReflect.Descriptor instead.
func (*Field_ListEntry) GetElemFullType ¶
func (x *Field_ListEntry) GetElemFullType() string
func (*Field_ListEntry) GetElemType ¶
func (x *Field_ListEntry) GetElemType() string
func (*Field_ListEntry) ProtoMessage ¶
func (*Field_ListEntry) ProtoMessage()
func (*Field_ListEntry) ProtoReflect ¶
func (x *Field_ListEntry) ProtoReflect() protoreflect.Message
func (*Field_ListEntry) Reset ¶
func (x *Field_ListEntry) Reset()
func (*Field_ListEntry) String ¶
func (x *Field_ListEntry) String() string
type Field_MapEntry ¶
type Field_MapEntry struct {
KeyType string `protobuf:"bytes,1,opt,name=key_type,json=keyType,proto3" json:"key_type,omitempty"`
ValueType string `protobuf:"bytes,2,opt,name=value_type,json=valueType,proto3" json:"value_type,omitempty"`
ValueFullType string `protobuf:"bytes,3,opt,name=value_full_type,json=valueFullType,proto3" json:"value_full_type,omitempty"`
// contains filtered or unexported fields
}
func (*Field_MapEntry) Descriptor
deprecated
func (*Field_MapEntry) Descriptor() ([]byte, []int)
Deprecated: Use Field_MapEntry.ProtoReflect.Descriptor instead.
func (*Field_MapEntry) GetKeyType ¶
func (x *Field_MapEntry) GetKeyType() string
func (*Field_MapEntry) GetValueFullType ¶
func (x *Field_MapEntry) GetValueFullType() string
func (*Field_MapEntry) GetValueType ¶
func (x *Field_MapEntry) GetValueType() string
func (*Field_MapEntry) ProtoMessage ¶
func (*Field_MapEntry) ProtoMessage()
func (*Field_MapEntry) ProtoReflect ¶
func (x *Field_MapEntry) ProtoReflect() protoreflect.Message
func (*Field_MapEntry) Reset ¶
func (x *Field_MapEntry) Reset()
func (*Field_MapEntry) String ¶
func (x *Field_MapEntry) String() string
type Metabook ¶
type Metabook struct {
MetasheetMap map[string]*Metasheet `` /* 185-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*Metabook) Descriptor
deprecated
func (*Metabook) GetMetasheetMap ¶
func (*Metabook) ProtoMessage ¶
func (*Metabook) ProtoMessage()
func (*Metabook) ProtoReflect ¶
func (x *Metabook) ProtoReflect() protoreflect.Message
type Metasheet ¶
type Metasheet struct {
Sheet string `protobuf:"bytes,1,opt,name=sheet,proto3" json:"sheet,omitempty"`
Alias string `protobuf:"bytes,2,opt,name=alias,proto3" json:"alias,omitempty"`
Namerow int32 `protobuf:"varint,3,opt,name=namerow,proto3" json:"namerow,omitempty"`
Typerow int32 `protobuf:"varint,4,opt,name=typerow,proto3" json:"typerow,omitempty"`
Noterow int32 `protobuf:"varint,5,opt,name=noterow,proto3" json:"noterow,omitempty"`
Datarow int32 `protobuf:"varint,6,opt,name=datarow,proto3" json:"datarow,omitempty"`
Nameline int32 `protobuf:"varint,7,opt,name=nameline,proto3" json:"nameline,omitempty"`
Typeline int32 `protobuf:"varint,8,opt,name=typeline,proto3" json:"typeline,omitempty"`
Transpose bool `protobuf:"varint,9,opt,name=transpose,proto3" json:"transpose,omitempty"`
// nested naming of namerow
Nested bool `protobuf:"varint,10,opt,name=nested,proto3" json:"nested,omitempty"`
Sep string `protobuf:"bytes,11,opt,name=sep,proto3" json:"sep,omitempty"`
Subsep string `protobuf:"bytes,12,opt,name=subsep,proto3" json:"subsep,omitempty"`
// merge multiple sheets with same schema to one.
// each element is:
// - a workbook name or Glob(https://pkg.go.dev/path/filepath#Glob) to merge (relative to this workbook): <Workbook>,
// then the sheet name is the same as this sheet.
// - or a workbook name (relative to this workbook) with a worksheet name: <Workbook>#<Worksheet>.
Merger []string `protobuf:"bytes,13,rep,name=merger,proto3" json:"merger,omitempty"`
// Tableau will merge adjacent rows with the same key. If the key cell is not set,
// it will be treated as the same as the most nearest key above the same column.
//
// This option is only useful for map or keyed-list.
AdjacentKey bool `protobuf:"varint,14,opt,name=adjacent_key,json=adjacentKey,proto3" json:"adjacent_key,omitempty"`
// Field presence is the notion of whether a protobuf field has a value. If set as true,
// in order to track presence for basic types (numeric, string, bytes, and enums), the
// generated .proto will add the `optional` label to them.
//
// Singular proto3 fields of basic types (numeric, string, bytes, and enums) which are defined
// with the optional label have explicit presence, like proto2 (this feature is enabled by default
// as release 3.15). Refer: https://github.com/protocolbuffers/protobuf/blob/main/docs/field_presence.md
FieldPresence bool `protobuf:"varint,15,opt,name=field_presence,json=fieldPresence,proto3" json:"field_presence,omitempty"`
// declares if sheet is a template config, which only generates protobuf IDL and not generates json data.
// NOTE: currently only used for XML protogen.
Template bool `protobuf:"varint,16,opt,name=template,proto3" json:"template,omitempty"`
// Sheet mode.
Mode tableaupb.Mode `protobuf:"varint,17,opt,name=mode,proto3,enum=tableau.Mode" json:"mode,omitempty"`
// Scatter converts sheets separately with same schema.
// each element is:
// - a workbook name or Glob(https://pkg.go.dev/path/filepath#Glob) which is relative to this workbook: <Workbook>,
// then the sheet name is the same as this sheet.
// - or a workbook name which is relative to this workbook with a worksheet name: <Workbook>#<Worksheet>.
Scatter []string `protobuf:"bytes,18,rep,name=scatter,proto3" json:"scatter,omitempty"`
// Whether all fields in this sheet are optional (field name existence).
// If set to true, then:
// - table formats (Excel/CSV): field's column can be absent.
// - document formats (XML/YAML): field's name can be absent.
Optional bool `protobuf:"varint,19,opt,name=optional,proto3" json:"optional,omitempty"`
// Sheet patch type.
Patch tableaupb.Patch `protobuf:"varint,20,opt,name=patch,proto3,enum=tableau.Patch" json:"patch,omitempty"`
// confgen: export JSON/Bin/Text files with parent dir created.
WithParentDir bool `protobuf:"varint,21,opt,name=with_parent_dir,json=withParentDir,proto3" json:"with_parent_dir,omitempty"`
// confgen(scatter): export JSON/Bin/Text filenames without book name prefix.
ScatterWithoutBookName bool `` /* 133-byte string literal not displayed */
// Labels are key/value pairs that are attached to sheet.
// Labels can be used to organize and to select subsets of sheets.
// For example:
// - "app:gamesvr,patch:merge" indicates app is gamesvr and patch is true.
// - "app:*" indicates all apps.
//
// This concept is much like it is in k8s, see
// https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/.
Labels map[string]string `` /* 154-byte string literal not displayed */
// //////// Loader related options below //////////
// Generate ordered map accessers
OrderedMap bool `protobuf:"varint,50,opt,name=ordered_map,json=orderedMap,proto3" json:"ordered_map,omitempty"`
// Generate index accessers, and multiple index columns are comma-separated.
// Format: <ColumnName>[@IndexName], if IndexName is not set, it will be this
// column’s parent struct type name.
//
// Composite indexes (or multicolumn indexes) are in the form: ([column1, column2, column3,...])[@IndexName]
//
// Examples:
// - ID
// - ID@Item
// - (ID,Type)
// - (ID,Type)@Item
// - ID, (ID,Type)@Item
//
// Generated APIs are:
//
// C++:
// - const std::vector<const STRUCT_TYPE*>& Find<IndexName>(INDEX_TYPE index) const;
// - const STRUCT_TYPE* FindFirst<IndexName>(INDEX_TYPE index);
Index string `protobuf:"bytes,51,opt,name=index,proto3" json:"index,omitempty"`
// Specify loader language options.
// Valid keys are: OrderedMap, Index.
// Different kvs must be seperated by ',' and one key value must be seperated by ':'.
// If one key doesn't exist in map, it means that this loader option is supported in all languages.
// Valid values are all combinations of "cpp", "go" with ' ' as seperator.
//
// Examples:
// - OrderedMap:cpp,Index:cpp go // ordered map supported in cpp, index supported in cpp and go
// - OrderedMap:cpp // ordered map supported in cpp, index supported in all languages
LangOptions map[string]string `` /* 183-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*Metasheet) Descriptor
deprecated
func (*Metasheet) GetAdjacentKey ¶
func (*Metasheet) GetDatarow ¶
func (*Metasheet) GetFieldPresence ¶
func (*Metasheet) GetLangOptions ¶
func (*Metasheet) GetNameline ¶
func (*Metasheet) GetNamerow ¶
func (*Metasheet) GetNoterow ¶
func (*Metasheet) GetOptional ¶
func (*Metasheet) GetOrderedMap ¶
func (*Metasheet) GetScatter ¶
func (*Metasheet) GetScatterWithoutBookName ¶
func (*Metasheet) GetTemplate ¶
func (*Metasheet) GetTranspose ¶
func (*Metasheet) GetTypeline ¶
func (*Metasheet) GetTyperow ¶
func (*Metasheet) GetWithParentDir ¶
func (*Metasheet) ProtoMessage ¶
func (*Metasheet) ProtoMessage()
func (*Metasheet) ProtoReflect ¶
func (x *Metasheet) ProtoReflect() protoreflect.Message
type StructDescriptor ¶
type StructDescriptor struct {
Fields []*StructDescriptor_Field `protobuf:"bytes,1,rep,name=fields,proto3" json:"fields,omitempty"`
// contains filtered or unexported fields
}
StructDescriptor represents struct type definition in sheet.
func (*StructDescriptor) Descriptor
deprecated
func (*StructDescriptor) Descriptor() ([]byte, []int)
Deprecated: Use StructDescriptor.ProtoReflect.Descriptor instead.
func (*StructDescriptor) GetFields ¶
func (x *StructDescriptor) GetFields() []*StructDescriptor_Field
func (*StructDescriptor) ProtoMessage ¶
func (*StructDescriptor) ProtoMessage()
func (*StructDescriptor) ProtoReflect ¶
func (x *StructDescriptor) ProtoReflect() protoreflect.Message
func (*StructDescriptor) Reset ¶
func (x *StructDescriptor) Reset()
func (*StructDescriptor) String ¶
func (x *StructDescriptor) String() string
type StructDescriptor_Field ¶
type StructDescriptor_Field struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
Type string `protobuf:"bytes,2,opt,name=type,proto3" json:"type,omitempty"`
// contains filtered or unexported fields
}
func (*StructDescriptor_Field) Descriptor
deprecated
func (*StructDescriptor_Field) Descriptor() ([]byte, []int)
Deprecated: Use StructDescriptor_Field.ProtoReflect.Descriptor instead.
func (*StructDescriptor_Field) GetName ¶
func (x *StructDescriptor_Field) GetName() string
func (*StructDescriptor_Field) GetType ¶
func (x *StructDescriptor_Field) GetType() string
func (*StructDescriptor_Field) ProtoMessage ¶
func (*StructDescriptor_Field) ProtoMessage()
func (*StructDescriptor_Field) ProtoReflect ¶
func (x *StructDescriptor_Field) ProtoReflect() protoreflect.Message
func (*StructDescriptor_Field) Reset ¶
func (x *StructDescriptor_Field) Reset()
func (*StructDescriptor_Field) String ¶
func (x *StructDescriptor_Field) String() string
type UnionDescriptor ¶
type UnionDescriptor struct {
Values []*UnionDescriptor_Value `protobuf:"bytes,1,rep,name=values,proto3" json:"values,omitempty"`
// contains filtered or unexported fields
}
UnionDescriptor represents union type definition in sheet.
func (*UnionDescriptor) Descriptor
deprecated
func (*UnionDescriptor) Descriptor() ([]byte, []int)
Deprecated: Use UnionDescriptor.ProtoReflect.Descriptor instead.
func (*UnionDescriptor) GetValues ¶
func (x *UnionDescriptor) GetValues() []*UnionDescriptor_Value
func (*UnionDescriptor) ProtoMessage ¶
func (*UnionDescriptor) ProtoMessage()
func (*UnionDescriptor) ProtoReflect ¶
func (x *UnionDescriptor) ProtoReflect() protoreflect.Message
func (*UnionDescriptor) Reset ¶
func (x *UnionDescriptor) Reset()
func (*UnionDescriptor) String ¶
func (x *UnionDescriptor) String() string
type UnionDescriptor_Value ¶
type UnionDescriptor_Value struct {
Number *int32 `protobuf:"varint,1,opt,name=number,proto3,oneof" json:"number,omitempty"`
// This is message type name, and the corresponding enum value name
// is generated as: "TYPE_" + strcase.ToScreamingSnake(name).
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
Alias string `protobuf:"bytes,3,opt,name=alias,proto3" json:"alias,omitempty"`
Fields []string `protobuf:"bytes,4,rep,name=fields,proto3" json:"fields,omitempty"`
// contains filtered or unexported fields
}
func (*UnionDescriptor_Value) Descriptor
deprecated
func (*UnionDescriptor_Value) Descriptor() ([]byte, []int)
Deprecated: Use UnionDescriptor_Value.ProtoReflect.Descriptor instead.
func (*UnionDescriptor_Value) GetAlias ¶
func (x *UnionDescriptor_Value) GetAlias() string
func (*UnionDescriptor_Value) GetFields ¶
func (x *UnionDescriptor_Value) GetFields() []string
func (*UnionDescriptor_Value) GetName ¶
func (x *UnionDescriptor_Value) GetName() string
func (*UnionDescriptor_Value) GetNumber ¶
func (x *UnionDescriptor_Value) GetNumber() int32
func (*UnionDescriptor_Value) ProtoMessage ¶
func (*UnionDescriptor_Value) ProtoMessage()
func (*UnionDescriptor_Value) ProtoReflect ¶
func (x *UnionDescriptor_Value) ProtoReflect() protoreflect.Message
func (*UnionDescriptor_Value) Reset ¶
func (x *UnionDescriptor_Value) Reset()
func (*UnionDescriptor_Value) String ¶
func (x *UnionDescriptor_Value) String() string
type Workbook ¶
type Workbook struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"` // book name without suffix
Options *tableaupb.WorkbookOptions `protobuf:"bytes,2,opt,name=options,proto3" json:"options,omitempty"`
Worksheets []*Worksheet `protobuf:"bytes,3,rep,name=worksheets,proto3" json:"worksheets,omitempty"`
Imports map[string]int32 `` // imported proto files
/* 156-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*Workbook) Descriptor
deprecated
func (*Workbook) GetImports ¶
func (*Workbook) GetOptions ¶
func (x *Workbook) GetOptions() *tableaupb.WorkbookOptions
func (*Workbook) GetWorksheets ¶
func (*Workbook) ProtoMessage ¶
func (*Workbook) ProtoMessage()
func (*Workbook) ProtoReflect ¶
func (x *Workbook) ProtoReflect() protoreflect.Message
type Worksheet ¶
type Worksheet struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
Note string `protobuf:"bytes,2,opt,name=note,proto3" json:"note,omitempty"`
Options *tableaupb.WorksheetOptions `protobuf:"bytes,3,opt,name=options,proto3" json:"options,omitempty"`
Fields []*Field `protobuf:"bytes,4,rep,name=fields,proto3" json:"fields,omitempty"`
// contains filtered or unexported fields
}
func (*Worksheet) Descriptor
deprecated
func (*Worksheet) GetOptions ¶
func (x *Worksheet) GetOptions() *tableaupb.WorksheetOptions
func (*Worksheet) ProtoMessage ¶
func (*Worksheet) ProtoMessage()
func (*Worksheet) ProtoReflect ¶
func (x *Worksheet) ProtoReflect() protoreflect.Message